@@ -6,14 +6,18 @@ import (
 	"strings"
 	"time"
 
-	imagev1 "github.com/openshift/api/image/v1"
-	v1 "github.com/openshift/api/samples/v1"
-	"github.com/openshift/cluster-samples-operator/pkg/cache"
-	"github.com/openshift/cluster-samples-operator/pkg/util"
 	"github.com/sirupsen/logrus"
+
 	corev1 "k8s.io/api/core/v1"
 	kerrors "k8s.io/apimachinery/pkg/api/errors"
 	kapis "k8s.io/apimachinery/pkg/apis/meta/v1"
+
+	imagev1 "github.com/openshift/api/image/v1"
+	v1 "github.com/openshift/api/samples/v1"
+
+	"github.com/openshift/cluster-samples-operator/pkg/cache"
+	"github.com/openshift/cluster-samples-operator/pkg/metrics"
+	"github.com/openshift/cluster-samples-operator/pkg/util"
 )
 
 func (h *Handler) processImageStreamWatchEvent(is *imagev1.ImageStream, deleted bool) error {
@@ -320,13 +324,13 @@ func (h *Handler) coreUpdateDockerPullSpec(oldreg, newreg string, oldies []strin
 			if strings.HasPrefix(oldreg, old) {
 				oldreg = strings.Replace(oldreg, old, newreg, 1)
 				logrus.Debugf("coreUpdatePull hasReg1 reg now %s", oldreg)
-			} else {
-				// the content from openshift/library has something odd in in ... replace the registry piece
-				parts := strings.Split(oldreg, "/")
-				oldreg = newreg + "/" + parts[1] + "/" + parts[2]
-				logrus.Debugf("coreUpdatePull hasReg2 reg now %s", oldreg)
+				return oldreg
 			}
 		}
+		// the content from openshift/library has something odd in in ... replace the registry piece
+		parts := strings.Split(oldreg, "/")
+		oldreg = newreg + "/" + parts[1] + "/" + parts[2]
+		logrus.Debugf("coreUpdatePull hasReg2 reg now %s", oldreg)
 	} else {
 		oldreg = newreg + "/" + oldreg
 		logrus.Debugf("coreUpdatePull no hasReg reg now %s", oldreg)
@@ -464,6 +468,7 @@ func (h *Handler) processImportStatus(is *imagev1.ImageStream, cfg *v1.Config) (
 							logrus.Warningf("attempted to initiate an imagestreamimport retry for imagestream/tag %s/%s but got err %v; simply moving on", is.Name, statusTag.Tag, err)
 							break
 						}
+						metrics.ImageStreamImportRetry(is.Name)
 						logrus.Printf("initiated an imagestreamimport retry for imagestream/tag %s/%s", is.Name, statusTag.Tag)
 
 					}
